@@ -13,6 +13,8 @@ import aws_cdk.aws_cloudfront._jsii
 import aws_cdk.aws_cloudfront_origins._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_cloudwatch_actions._jsii
+import aws_cdk.aws_codeartifact._jsii
+import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_events_targets._jsii
 import aws_cdk.aws_iam._jsii
@@ -26,12 +28,13 @@ import aws_cdk.aws_s3_deployment._jsii
 import aws_cdk.aws_sns._jsii
 import aws_cdk.aws_sqs._jsii
 import aws_cdk.core._jsii
+import aws_cdk.custom_resources._jsii
 import aws_cdk.cx_api._jsii
 import cdk_watchful._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "construct-hub", "0.1.72", __name__[0:-6], "construct-hub@0.1.72.jsii.tgz"
+    "construct-hub", "0.1.75", __name__[0:-6], "construct-hub@0.1.75.jsii.tgz"
 )
 
 __all__ = [
